from pythermogis.thermogis_classes.doublet import calculate_performance_across_dimensions


def calculate_doublet_performance(input_data):
    """Testing API"""
    return calculate_performance_across_dimensions(input_data)
